pub struct Syslog { /* private fields */ }Expand description
MakeWriter that logs to syslog via libc’s syslog() function.
Level Mapping
tracing Levels are mapped to syslog severities as follows:
Level::ERROR => Severity::LOG_ERR,
Level::WARN => Severity::LOG_WARNING,
Level::INFO => Severity::LOG_NOTICE,
Level::DEBUG => Severity::LOG_INFO,
Level::TRACE => Severity::LOG_DEBUG,Note: the mapping is lossless, but the corresponding syslog severity
names differ from tracing’s level names towards the bottom. syslog
does not have a level lower than LOG_DEBUG, so this is unavoidable.
Examples
Initializing a global logger that writes to syslog with an identity of example-program
and the default syslog options and facility:
let identity = std::ffi::CStr::from_bytes_with_nul(b"example-program\0").unwrap();
let (options, facility) = Default::default();
let syslog = syslog_tracing::Syslog::new(identity, options, facility).unwrap();
tracing_subscriber::fmt().with_writer(syslog).init();Implementations
Sourceimpl Syslog
impl Syslog
Sourcepub fn new(
identity: impl Into<Cow<'static, CStr>>,
options: Options,
facility: Facility,
) -> Option<Self>
pub fn new( identity: impl Into<Cow<'static, CStr>>, options: Options, facility: Facility, ) -> Option<Self>
Creates a [tracing] MakeWriter that writes to syslog.
This calls libc::openlog() to initialize the logger. The corresponding
libc::closelog() call happens when the returned logger is dropped.
If a logger already exists, returns None.
Examples
Creating a syslog MakeWriter with an identity of example-program and
the default syslog options and facility:
use syslog_tracing::Syslog;
let identity = std::ffi::CStr::from_bytes_with_nul(b"example-program\0").unwrap();
let (options, facility) = Default::default();
let syslog = Syslog::new(identity, options, facility).unwrap();Two loggers cannot coexist, since libc::syslog() writes to a global logger:
let syslog = Syslog::new(identity, options, facility).unwrap();
assert!(Syslog::new(identity, options, facility).is_none());Sourcepub fn invalid_chars(self, cfg: InvalidCharAction) -> Self
pub fn invalid_chars(self, cfg: InvalidCharAction) -> Self
Set the action to take when a message cannot be logged as is because it contains invalid characters.